@@ -8,8 +8,9 @@ import SubscriptionDto
 @Mapper()
 class SubscriptionModelMapper:
 
-    @MapperMethod(requestClass=[[SubscriptionDto.SubscriptionRequestDto]], responseClass=[[SubscriptionModel.SubscriptionModel]])
+    @MapperMethod(requestClass=[[SubscriptionDto.SubscriptionRequestDto], str], responseClass=[[SubscriptionModel.SubscriptionModel]])
     def fromRequestDtoListToModelList(self, dtoList, modelList):
+        self.overrideAllModelOriginKey(originKey, modelList)
         return modelList
 
 
@@ -18,8 +19,9 @@ class SubscriptionModelMapper:
         return dtoList
 
 
-    @MapperMethod(requestClass=[SubscriptionDto.SubscriptionRequestDto], responseClass=[SubscriptionModel.SubscriptionModel])
-    def fromRequestDtoToModel(self, dto, model):
+    @MapperMethod(requestClass=[SubscriptionDto.SubscriptionRequestDto, str], responseClass=[SubscriptionModel.SubscriptionModel])
+    def fromRequestDtoToModel(self, dto, originKey, model):
+        self.overrideModelOriginKey(originKey, model)
         return model
 
 
@@ -34,3 +36,15 @@ class SubscriptionModelMapper:
         model.onErrorUrl = ConverterStatic.getValueOrDefault(dto.onErrorUrl, model.onErrorUrl)
         model.maxTries = ConverterStatic.getValueOrDefault(dto.maxTries, model.maxTries)
         model.backOff = ConverterStatic.getValueOrDefault(dto.backOff, model.backOff)
+        model.headers = ConverterStatic.getValueOrDefault(dto.headers, model.headers)
+
+
+    @MapperMethod(requestClass=[str, SubscriptionModel.SubscriptionModel])
+    def overrideModelOriginKey(self, originKey, model):
+        model.originKey = ConverterStatic.getValueOrDefault(originKey, model.originKey)
+
+
+    @MapperMethod(requestClass=[str, [SubscriptionModel.SubscriptionModel]])
+    def overrideAllModelOriginKey(self, originKey, modelList):
+        for model in modelList:
+            self.overrideModelOriginKey(originKey, model)
